package com.ruoyi.mall.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallTargetMapper;
import com.ruoyi.mall.domain.MallTarget;
import com.ruoyi.mall.service.IMallTargetService;

/**
 * 营销目标Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-01-17
 */
@Service
public class MallTargetServiceImpl implements IMallTargetService 
{
    @Autowired
    private MallTargetMapper mallTargetMapper;

    /**
     * 查询营销目标
     * 
     * @param id 营销目标主键
     * @return 营销目标
     */
    @Override
    public MallTarget selectMallTargetById(Integer id)
    {
        return mallTargetMapper.selectMallTargetById(id);
    }

    /**
     * 查询营销目标列表
     * 
     * @param mallTarget 营销目标
     * @return 营销目标
     */
    @Override
    public List<MallTarget> selectMallTargetList(MallTarget mallTarget)
    {
        return mallTargetMapper.selectMallTargetList(mallTarget);
    }

    /**
     * 新增营销目标
     * 
     * @param mallTarget 营销目标
     * @return 结果
     */
    @Override
    public int insertMallTarget(MallTarget mallTarget)
    {
        return mallTargetMapper.insertMallTarget(mallTarget);
    }

    /**
     * 修改营销目标
     * 
     * @param mallTarget 营销目标
     * @return 结果
     */
    @Override
    public int updateMallTarget(MallTarget mallTarget)
    {
        return mallTargetMapper.updateMallTarget(mallTarget);
    }

    /**
     * 批量删除营销目标
     * 
     * @param ids 需要删除的营销目标主键
     * @return 结果
     */
    @Override
    public int deleteMallTargetByIds(Integer[] ids)
    {
        return mallTargetMapper.deleteMallTargetByIds(ids);
    }

    /**
     * 删除营销目标信息
     * 
     * @param id 营销目标主键
     * @return 结果
     */
    @Override
    public int deleteMallTargetById(Integer id)
    {
        return mallTargetMapper.deleteMallTargetById(id);
    }
}
