package com.ruoyi.mall.controller;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallTarget;
import com.ruoyi.mall.service.IMallTargetService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 营销目标Controller
 * 
 * @author ruoyi
 * @date 2022-01-17
 */
@RestController
@RequestMapping("/mall/mallTarget")
public class MallTargetController extends BaseController
{
    @Autowired
    private IMallTargetService mallTargetService;

    /**
     * 查询营销目标列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallTarget:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallTarget mallTarget)
    {
        startPage();
        List<MallTarget> list = mallTargetService.selectMallTargetList(mallTarget);
        return getDataTable(list);
    }

    /**
     * 导出营销目标列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallTarget:export')")
    @Log(title = "营销目标", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallTarget mallTarget)
    {
        List<MallTarget> list = mallTargetService.selectMallTargetList(mallTarget);
        ExcelUtil<MallTarget> util = new ExcelUtil<MallTarget>(MallTarget.class);
        return util.exportExcel(list, "营销目标数据");
    }

    /**
     * 获取营销目标详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallTarget:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(mallTargetService.selectMallTargetById(id));
    }

    /**
     * 新增营销目标
     */
    @PreAuthorize("@ss.hasPermi('mall:mallTarget:add')")
    @Log(title = "营销目标", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallTarget mallTarget)
    {
        mallTarget.setUpdateAt(DateUtils.getTime());
        return toAjax(mallTargetService.insertMallTarget(mallTarget));
    }

    /**
     * 修改营销目标
     */
    @PreAuthorize("@ss.hasPermi('mall:mallTarget:edit')")
    @Log(title = "营销目标", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallTarget mallTarget)
    {
        mallTarget.setUpdateAt(DateUtils.getTime());
        return toAjax(mallTargetService.updateMallTarget(mallTarget));
    }

    /**
     * 删除营销目标
     */
    @PreAuthorize("@ss.hasPermi('mall:mallTarget:remove')")
    @Log(title = "营销目标", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(mallTargetService.deleteMallTargetByIds(ids));
    }
}
